==> haskell-unsafe-0.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unsafe.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unsafe
version: 0.0
id: unsafe-0.0-BIrI9nXOqv1FDJhoFAi4jR
key: unsafe-0.0-BIrI9nXOqv1FDJhoFAi4jR
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://code.haskell.org/~thielema/unsafe/
synopsis: Unified interface to unsafe functions
description:
    SafeHaskell introduced the notion of safe and unsafe modules.
    In order to make as many as possible modules \"safe\",
    the well-known unsafe functions were moved to distinguished modules.
    This makes it hard to write packages that work
    with both old and new versions of GHC.
    This package provides a single module @System.Unsafe@
    that exports the unsafe functions from the base package.
    It provides them in a style ready for qualification,
    that is, you should import them by
    .
    > import qualified System.Unsafe as Unsafe
    .
    The package also contains a script called @rename-unsafe.sh@.
    It replaces all occurrences of the original identifiers
    with the qualified identifiers from this package.
    You still have to adapt the import commands.
    It uses the @darcs-replace-rec@ script from the @darcs-scripts@ package.
category: Control
author: Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
indefinite: False
exposed-modules:
    System.Unsafe
abi: 7df145c64396018dcd2e7fe561a83a4f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/unsafe-0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/unsafe-0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/unsafe-0.0
hs-libraries: HSunsafe-0.0-BIrI9nXOqv1FDJhoFAi4jR
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-unsafe/html/unsafe.haddock
haddock-html: /usr/share/doc/haskell-unsafe/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unsafe-0.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unsafe.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unsafe
version: 0.0
id: unsafe-0.0-GMfN8SJyoiBOcfugVwnQq
key: unsafe-0.0-GMfN8SJyoiBOcfugVwnQq
license: BSD-3-Clause
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
author: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://code.haskell.org/~thielema/unsafe/
synopsis: Unified interface to unsafe functions
description:
    SafeHaskell introduced the notion of safe and unsafe modules.
    In order to make as many as possible modules \"safe\",
    the well-known unsafe functions were moved to distinguished modules.
    This makes it hard to write packages that work
    with both old and new versions of GHC.
    This package provides a single module @System.Unsafe@
    that exports the unsafe functions from the base package.
    It provides them in a style ready for qualification,
    that is, you should import them by
    .
    > import qualified System.Unsafe as Unsafe
    .
    The package also contains a script called @rename-unsafe.sh@.
    It replaces all occurrences of the original identifiers
    with the qualified identifiers from this package.
    You still have to adapt the import commands.
    It uses the @darcs-replace-rec@ script from the @darcs-scripts@ package.
category: Control
abi: a397e4371ccccc2e517eaf2a44e24dc0
exposed: True
exposed-modules:
    System.Unsafe
import-dirs: /usr/lib/ghc-8.4.3/site-local/unsafe-0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/unsafe-0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/unsafe-0.0
hs-libraries: HSunsafe-0.0-GMfN8SJyoiBOcfugVwnQq
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-unsafe/html/unsafe.haddock
haddock-html: /usr/share/doc/haskell-unsafe/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
